import { dataSource } from "../../../data-source";
import { qualification } from "../../../entity/settings/qualification";
import { memberQualifications } from "../../../entity/club/member/memberQualifications";
import InternalException from "../../../exceptions/internalException";
import {
  CreateMemberQualificationCommand,
  DeleteMemberQualificationCommand,
  UpdateMemberQualificationCommand,
} from "./memberQualificationCommand";
import { member } from "../../../entity/club/member/member";

export default abstract class MemberQualificationCommandHandler {
  /**
   * @description create memberQualification
   * @param CreateMemberQualificationCommand
   * @returns {Promise<number>}
   */
  static async create(createMemberQualification: CreateMemberQualificationCommand): Promise<number> {
    return await dataSource
      .createQueryBuilder()
      .insert()
      .into(memberQualifications)
      .values({
        note: createMemberQualification.note,
        start: createMemberQualification.start,
        memberId: createMemberQualification.memberId,
        qualificationId: createMemberQualification.qualificationId,
      })
      .execute()
      .then((result) => {
        return result.identifiers[0].id;
      })
      .catch((err) => {
        throw new InternalException("Failed creating memberQualification", err);
      });
  }

  /**
   * @description update memberQualification
   * @param UpdateMemberQualificationCommand
   * @returns {Promise<void>}
   */
  static async update(updateMemberQualification: UpdateMemberQualificationCommand): Promise<void> {
    return await dataSource
      .createQueryBuilder()
      .update(memberQualifications)
      .set({
        note: updateMemberQualification.note,
        start: updateMemberQualification.start,
        end: updateMemberQualification.end,
        terminationReason: updateMemberQualification.terminationReason,
        qualificationId: updateMemberQualification.qualificationId,
      })
      .where("id = :id", { id: updateMemberQualification.id })
      .andWhere("memberId = :memberId", { memberId: updateMemberQualification.memberId })
      .execute()
      .then(() => {})
      .catch((err) => {
        throw new InternalException("Failed updating memberQualification", err);
      });
  }

  /**
   * @description delete memberQualification
   * @param DeleteMemberQualificationCommand
   * @returns {Promise<void>}
   */
  static async delete(deletMemberQualification: DeleteMemberQualificationCommand): Promise<void> {
    return await dataSource
      .createQueryBuilder()
      .delete()
      .from(memberQualifications)
      .where("id = :id", { id: deletMemberQualification.id })
      .andWhere("memberId = :memberId", { memberId: deletMemberQualification.memberId })
      .execute()
      .then(() => {})
      .catch((err) => {
        throw new InternalException("Failed deleting memberQualification", err);
      });
  }
}
