import { dataSource } from "../../../data-source";
import { qualification } from "../../../entity/settings/qualification";
import InternalException from "../../../exceptions/internalException";
import {
  CreateQualificationCommand,
  DeleteQualificationCommand,
  UpdateQualificationCommand,
} from "./qualificationCommand";

export default abstract class QualificationCommandHandler {
  /**
   * @description create qualification
   * @param CreateQualificationCommand
   * @returns {Promise<number>}
   */
  static async create(createQualification: CreateQualificationCommand): Promise<number> {
    return await dataSource
      .createQueryBuilder()
      .insert()
      .into(qualification)
      .values({
        qualification: createQualification.qualification,
        description: createQualification.description,
      })
      .execute()
      .then((result) => {
        return result.identifiers[0].id;
      })
      .catch((err) => {
        throw new InternalException("Failed creating qualification", err);
      });
  }

  /**
   * @description update qualification
   * @param UpdateQualificationCommand
   * @returns {Promise<void>}
   */
  static async update(updateQualification: UpdateQualificationCommand): Promise<void> {
    return await dataSource
      .createQueryBuilder()
      .update(qualification)
      .set({
        qualification: updateQualification.qualification,
        description: updateQualification.description,
      })
      .where("id = :id", { id: updateQualification.id })
      .execute()
      .then(() => {})
      .catch((err) => {
        throw new InternalException("Failed updating qualification", err);
      });
  }

  /**
   * @description delete qualification
   * @param DeleteQualificationCommand
   * @returns {Promise<void>}
   */
  static async delete(deletQualification: DeleteQualificationCommand): Promise<void> {
    return await dataSource
      .createQueryBuilder()
      .delete()
      .from(qualification)
      .where("id = :id", { id: deletQualification.id })
      .execute()
      .then(() => {})
      .catch((err) => {
        throw new InternalException("Failed deleting qualification", err);
      });
  }
}
